@@ -18,6 +18,7 @@ from pathlib import Path
 from typing import NoReturn
 
 import discord
+import rich
 
 # Set the event loop policies here so any subsequent `new_event_loop()`
 # calls, in particular those as a result of the following imports,
@@ -84,8 +85,7 @@ def debug_info():
         os_info = platform.mac_ver()
         osver = "Mac OSX {} {}".format(os_info[0], os_info[2])
     else:
-        os_info = distro.linux_distribution()
-        osver = "{} {}".format(os_info[0], os_info[1]).strip()
+        osver = f"{distro.name()} {distro.version()}".strip()
     user_who_ran = getpass.getuser()
     info = (
         "Debug Info for Red\n\n"
@@ -395,10 +395,12 @@ async def run_bot(red: Red, cli_flags: Namespace) -> None:
                 sys.exit(0)
         sys.exit(1)
     except discord.PrivilegedIntentsRequired:
-        print(
+        console = rich.get_console()
+        console.print(
             "Red requires all Privileged Intents to be enabled.\n"
             "You can find out how to enable Privileged Intents with this guide:\n"
-            "https://docs.discord.red/en/stable/bot_application_guide.html#enabling-privileged-intents"
+            "https://docs.discord.red/en/stable/bot_application_guide.html#enabling-privileged-intents",
+            style="red",
         )
         sys.exit(1)
 
